def buduca_hodnota(vklad, urokova_miera, roky):
    ''' Vráti stav účtu pre zadaný vklad, úrokovú mieru a počet rokov

    :param vklad: počiatočná výška investície
    :type vklad: float
    :param urokova_miera: úroková miera v percentách
    :type urokova_miera: float
    :param roky: dĺžka obdobia investície v rokoch
    :type roky: int
    :return: výsledná výška investície
    :rtype: float
    :raises Exception: Ak niektorá hodnota nie je číslo alebo
    niektorá zo vstupných hodnôt nie je kladná.'
    '''
    try:
        vklad = float(vklad)
        urokova_miera = float(urokova_miera)
        roky = int(roky)
    except ValueError:
        # nečíselný vstup
        raise ValueError('Nečíselná hodnota pre výšku vkladu, úrokovú mieru alebo počet rokov.')
    if vklad <= 0 or urokova_miera <= 0 or roky <= 0:
        # nekladné hodnoty na vstupe
        raise ValueError('Niektorá zo vstupných hodnôt nie je kladná.')
    # výpočet stavu účtu
    vysledok = vklad * (1 + urokova_miera / 100) ** roky
    return vysledok


# načítanie vstupných hodnôt
vklad = input('Zadaj výšku investície: ')
urokova_miera = input('Zadaj úrokovú mieru: ')
pocet_rokov = input('Dĺžka obdobia investície (celé roky): ')

try:
    print(f'Výška investície po {pocet_rokov} rokoch: {buduca_hodnota(vklad, urokova_miera, pocet_rokov)} EUR')
except ValueError as chyba:
    print(chyba)
