def existuje_trojuholnik(a, b, c):
    ''' Vráti, či existuje trojuholník so zadanými dĺžkami strán

    :param a: dĺžka strany a
    :type a: float
    :param b: dĺžka strany b
    :type b: float
    :param c: dĺžka strany c
    :type c: float
    :return: True, ak trojuholník existuje, inak False
    :rtype: bool
    '''
    try:
        # overíme, či hodnoty predstavujú čísla
        a = float(a)
        b = float(b)
        c = float(c)
    except ValueError:
        return False
    if a <= 0 or b <= 0 or c <= 0:
        # ak čo i len jedna z hodnôt je nekladná
        return False

    if not (a + b > c and a + c > b and b + c > a):
        # ak neplatí trojuholníková nerovnosť
        return False

    return True


def obsah_trojuholnika(a, b, c):
    ''' Vráti obsah trojuholníka so zadanými dĺžkami strán

    :param a: dĺžka strany a
    :type a: float
    :param b: dĺžka strany b
    :type b: float
    :param c: dĺžka strany c
    :type c: float
    :return: obsah trojuholníka s dĺžkami strán a, b, c
    :rtype: float
    :raises ValueError: Ak trojuholník s uvedenými stranami neexistuje
    '''
    if not existuje_trojuholnik(a, b, c):
        raise ValueError('Pre zadané dĺžky strán trojuholník neexistuje.')

    a = float(a)
    b = float(b)
    c = float(c)

    s = (a + b + c) / 2
    obsah = (s * (s - a) * (s - b) * (s - c)) ** 0.5
    return obsah


def vyska_najmu(a, b, c):
    ''' Vráti výšku nájmu v EUR za trojuholníkový pozemok

    :param a: dĺžka strany a
    :type a: float
    :param b: dĺžka strany b
    :type b: float
    :param c: dĺžka strany c
    :type c: float
    :return: výška nájmu
    :rtype: float
    :raises ValueError: Ak pozemok s danými stranami neexistuje
    '''
    try:
        plocha_pozemku = obsah_trojuholnika(a, b, c)
    except ValueError:
        raise ValueError('Chybne zadané rozmery pozemku')
    najom = round(0.75 * plocha_pozemku, 2)
    return najom


strana_a = input('Zadaj stranu 1 pozemku: ')
strana_b = input('Zadaj stranu 2 pozemku: ')
strana_c = input('Zadaj stranu 3 pozemku: ')
try:
    najom = vyska_najmu(strana_a, strana_b, strana_c)
except ValueError as chyba:
    print(chyba)
else:
    print(f'Výška nájmu za pozemok je {najom} EUR.')
