import random


def nacitaj_zo_suboru(subor):
    ''' Prečíta slová zo súboru a vráti ich zoznam
    :param subor: názov súboru
    :type subor: str
    :return: zoznam slov
    :rtype: list of str
    '''
    try:
        with open(subor, 'r', encoding='utf-8') as f:
            data = f.readlines()
    except FileNotFoundError:
        raise FileNotFoundError(f'Súbor slov "{subor}" sa nenašiel.')
    except OSError:
        raise OSError(f'Súbor slov "{subor}" sa nepodarilo otvoriť.')
    vysledok = [slovo.strip() for slovo in data]
    return vysledok


def rozdel_slova(spolocny_zoznam, prvy_zoznam, druhy_zoznam, pocet):
    ''' Zamieša slová v zozname spolocny_zoznam a do každého zo zoznamov (prvy_zoznam, druhy_zoznam)
    presunie pocet kariet

    :param spolocny_zoznam: spoločný zoznam slov
    :type spolocny_zoznam: list of str
    :param prvy_zoznam: prvý zoznam
    :type prvy_zoznam: list of str
    :param druhy_zoznam: druhý zoznam
    :type druhy_zoznam: list of str
    :param pocet: počet kariet na presunutie
    :type pocet: int
    '''
    if 2 * pocet > len(spolocny_zoznam):
        raise ValueError('Celkový počet slov je nedostatočný')
    pomocny = spolocny_zoznam.copy()
    random.shuffle(pomocny)
    prvy_zoznam.extend(pomocny[:pocet])
    druhy_zoznam.extend(pomocny[pocet:2 * pocet])
    spolocny_zoznam.clear()
    spolocny_zoznam.extend(pomocny[2 * pocet:])
    # alebo
    # random.shuffle(spolocny_zoznam)
    # prvy_zoznam.extend(spolocny_zoznam[:pocet])
    # druhy_zoznam.extend(spolocny_zoznam[pocet:2 * pocet])
    # del spolocny_zoznam[:2 * pocet]


def zoznam_slov_zacinajucich_pismenom(zoznam_slov, pismeno):
    ''' Vráti zoznam slov zo zoznam_slov začínajúcich písmenom pismeno

    :param zoznam_slov: zoznam slov
    :type zoznam_slov: list of str
    :param pismeno: písmeno abecedy
    :type pismeno: str
    :return: zoznam slov začínajúcich písmenom pismeno
    :rtype: list of str
    '''
    vysledok = [slovo for slovo in zoznam_slov if slovo[0] == pismeno]
    return vysledok


def zoznam_slov_konciacich_pismenom(zoznam_slov, pismeno):
    ''' Vráti zoznam slov zo zoznam_slov končiacich písmenom pismeno

    :param zoznam_slov: zoznam slov
    :type zoznam_slov: list of str
    :param pismeno: písmeno abecedy
    :type pismeno: str
    :return: zoznam slov končiacich písmenom pismeno
    :rtype: list of str
    '''
    vysledok = [slovo for slovo in zoznam_slov if slovo[-1] == pismeno]
    return vysledok


def nahodne_slovo_zacinajuce_na_pismeno(zoznam_slov, pismeno):
    ''' Vráti náhodné slovo zo zoznam_slov, ktoré začína písmenom pismeno

    :param zoznam_slov: zoznam slov
    :type zoznam_slov: list of str
    :param pismeno: písmeno abecedy
    :type pismeno: str
    :return: slovo začínajúce na pismeno
    :rtype: list of str
    :raise ValueError: ak také slovo neexistuje
    '''

    slova_na_pismeno = zoznam_slov_zacinajucich_pismenom(zoznam_slov, pismeno)
    try:
        pismeno = random.choice(slova_na_pismeno)
        return pismeno
    except IndexError:
        raise ValueError('Požadované slovo v zozname neexistuje')


def nahodne_slovo_konciace_na_pismeno(zoznam_slov, pismeno):
    ''' Vráti náhodné slovo zo zoznam_slov, ktoré končí písmenom pismeno

    :param zoznam_slov: zoznam slov
    :type zoznam_slov: list of str
    :param pismeno: písmeno abecedy
    :type pismeno: str
    :return: slovo končiace na pismeno
    :rtype: list of str
    :raise ValueError: ak také slovo neexistuje
    '''
    slova_na_pismeno = zoznam_slov_konciacich_pismenom(zoznam_slov, pismeno)
    try:
        pismeno = random.choice(slova_na_pismeno)
        return pismeno
    except IndexError:
        raise ValueError('Požadované slovo v zozname neexistuje')


def zoznam_slov_so_zaciatkom_a_koncom(zoznam_slov, zaciatocne_pismeno, koncove_pismeno):
    ''' Vráti zoznam slov zo zoznam_slov začínaucich písmenom zaciatocne_pismeno a
    končiacich písmenom koncove_pismeno

    :param zoznam_slov: zoznam slov
    :type zoznam_slov: list of str
    :param zaciatocne_pismeno: písmeno abecedy
    :type pismeno: str
    :param koncove_pismeno: písmeno abecedy
    :type pismeno: str
    :return: zoznam slov začínajúcich a končiacich zadanými písmenami
    :rtype: list of str
    '''
    vysledok = zoznam_slov_zacinajucich_pismenom(zoznam_slov, zaciatocne_pismeno)
    vysledok = zoznam_slov_konciacich_pismenom(vysledok, koncove_pismeno)
    return vysledok


def usporiadaj_abecedne(zoznam_slov):
    ''' Uporiada zoznam_slov podľa abecedy

    :param zoznam_slov: zoznam slov
    :type zoznam_slov: list of str
    '''
    zoznam_slov.sort()


def usporiadaj_abecedne_naopak(zoznam_slov):
    ''' Uporiada zoznam_slov podľa abecedy odzadu

    :param zoznam_slov: zoznam slov
    :type zoznam_slov: list of str
    '''
    usporiadaj_abecedne(zoznam_slov)
    zoznam_slov.reverse()


def odstran_slova_zo_zoznamu(zoznam_slov, zoznam_na_odstranenie):
    ''' Zo zoznamu zoznam_slov odstráni slová zo zoznamu zoznam_na_odstranenie

    :param zoznam_slov: zoznam slov
    :type zoznam_slov: list of str
    :param zoznam_na_odstranenie: zoznam slov na odstránenie
    :type zoznam_na_odstranenie: list of str
    '''
    for slovo in zoznam_na_odstranenie:
        if slovo in zoznam_slov:
            zoznam_slov.remove(slovo)
        if slovo[::-1] in zoznam_slov:
            zoznam_slov.remove(slovo[::-1])


def hodnota_zoznamu(zoznam_slov):
    ''' Vráti hodnotu zoznamu slov

    :param zoznam_slov: zoznam slov
    :type zoznam_slov: list of str
    :return: hodnota zoznamu
    :rtype: iunt
    '''
    znaky_s_diakritikou = 'áäčďéíĺľňóôŕřšťúýž'
    hodnota = len(zoznam_slov)
    for slovo in zoznam_slov:
        if slovo == slovo[::-1]:
            hodnota = hodnota + 1
        for znak in slovo:
            if znak in znaky_s_diakritikou:
                hodnota = hodnota + 1
    return hodnota


def pridaj_karty(spolocny_zoznam, zoznam, pismeno):
    ''' Presúva karty zo spolocny_zoznam do zoznam až kým nenarazí na slovo s písmenom pismeno.
    Toto slovo presunie na koniec spolocny_zoznam

    :param spolocny_zoznam: spoločný zoznam slov z ktorého pridávame
    :type spolocny_zoznam: list of str
    :param zoznam: zoznam slov do ktorého pridávame
    :type zoznam: list of str
    :param pismeno: hľadané písmeno
    :type pismeno: str
    '''
    idx = 0
    while idx < len(spolocny_zoznam) and pismeno not in spolocny_zoznam[idx]:
        idx = idx + 1
    if idx == len(spolocny_zoznam):  # slovo so zadanym pismenom v spolocnom zozname nie je
        zoznam.extend(spolocny_zoznam)
        spolocny_zoznam.clear()
    else:
        zoznam.extend(spolocny_zoznam[:idx])
        pomocny = spolocny_zoznam[idx + 1:]
        pomocny.append(spolocny_zoznam[idx])
        spolocny_zoznam.clear()
        spolocny_zoznam.extend(pomocny)
        # alebo
        # zoznam.extend(spolocny_zoznam[:idx])
        # spolocny_zoznam.append(spolocny_zoznam[idx])
        # del spolocny_zoznam[:idx+1]


spolocny_zoznam = nacitaj_zo_suboru('slova.txt')

hanka = []
zuzka = []
rozdel_slova(spolocny_zoznam, hanka, zuzka, 5)
print(f'{hanka=}')
print(f'{zuzka=}')

print(f'Hankine slova zacinajuce na d: {zoznam_slov_zacinajucich_pismenom(hanka, "d")}')
print(f'Hankine slova končiace na r: {zoznam_slov_konciacich_pismenom(hanka, "r")}')

print('Náhodné slovo z Hankinho zoznamu začínajúce na d: ', end='')
try:
    print(nahodne_slovo_zacinajuce_na_pismeno(hanka, "d"))
except ValueError as chyba:
    print(chyba)

print('Náhodné slovo z Hankinho zoznamu končiace na r: ', end='')
try:
    print(nahodne_slovo_konciace_na_pismeno(hanka, "r"))
except ValueError as chyba:
    print(chyba)

print(f'Hankine slova zacinajuce na d a končiace na r: {zoznam_slov_so_zaciatkom_a_koncom(hanka, "d", "r")}')

usporiadaj_abecedne(hanka)
print(f'Hankine slova abecedne: {hanka}')
usporiadaj_abecedne_naopak(hanka)
print(f'Hankine slova abecedne odzadu: {hanka}')

slova_na_d = zoznam_slov_zacinajucich_pismenom(hanka, 'd')
odstran_slova_zo_zoznamu(hanka, slova_na_d)
print(f'Hankin zoznam bez slov začínajúcich na d: {hanka}')

print(f'Hodnota Hankinho zoznamu: {hodnota_zoznamu(hanka)}')

pridaj_karty(spolocny_zoznam, hanka, 'a')
print(f'Hankin zoznam do ktorého sa pridávali slová, kým sa nenašlo slovo s a: {hanka}')
