def trvanie_trasy(zaznam):
    ''' Vráti čas potrebný na prejdenie trasy

    :param zaznam: záznam, z výškomera
    :type zaznam: list of float
    :return: čas na prejdenie trasy v minútach
    :rtype: int
    '''
    return len(zaznam) - 1


def najvyssi_bod(zaznam):
    ''' Vráti nadmorskú výšku najvyššieho bodu trasy

    :param zaznam: záznam z výškomera
    :type zaznam: list of float
    :return: výška najvyššieho bodu trasy v m
    :rtype: float
    '''
    return max(zaznam)


def celkove_stupanie(zaznam):
    ''' Vráti celkové stúpanie trasy, súčet všetkých stúpaní

    :param zaznam: záznam z výškomera
    :type zaznam: list of float
    :return: celkové stúpanie
    :rtype: float
    '''
    stupanie = 0
    for idx in range(len(zaznam) - 1):
        rozdiel = zaznam[idx + 1] - zaznam[idx]
        if rozdiel > 0:
            stupanie = stupanie + rozdiel
    return stupanie


def celkove_klesanie(zaznam):
    ''' Vráti celkové klesanie trasy, súčet všetkých klesaní

    :param zaznam: záznam z výškomera
    :type zaznam: list of float
    :return: celkové klesanie
    :rtype: float
    '''
    klesanie = 0
    for idx in range(len(zaznam) - 1):
        rozdiel = zaznam[idx] - zaznam[idx + 1]
        if rozdiel > 0:
            klesanie = klesanie + rozdiel
    return klesanie


def najdlhsie_stupanie(zaznam):
    ''' Vráti trvanie úseku v minútach, v ktorom sa najdlhšie stúpalo

    :param zaznam: záznam z výškomera
    :type zaznam: list of float
    :return: trvanie najdlhšieho stúpajúceho úseku
    :rtype: int
    '''
    naj_cas_stupania = 0
    akt_cas_stupania = 0
    for idx in range(len(zaznam) - 1):
        if zaznam[idx] < zaznam[idx + 1]:
            akt_cas_stupania = akt_cas_stupania + 1
            if akt_cas_stupania > naj_cas_stupania:
                naj_cas_stupania = akt_cas_stupania
        else:
            akt_cas_stupania = 0
    return naj_cas_stupania


def najdlhsie_klesanie(zaznam):
    ''' Vráti trvanie úseku v minútach, v ktorom sa najdlhšie klesalo

    :param zaznam: záznam z výškomera
    :type zaznam: list of float
    :return: trvanie najdlhšieho klesajúceho úseku
    :rtype: int
    '''
    naj_cas_klesania = 0
    akt_cas_klesania = 0
    for idx in range(len(zaznam) - 1):
        if zaznam[idx] > zaznam[idx + 1]:
            akt_cas_klesania = akt_cas_klesania + 1
            if akt_cas_klesania > naj_cas_klesania:
                naj_cas_klesania = akt_cas_klesania
        else:
            akt_cas_klesania = 0
    return naj_cas_klesania


def posun_vysky(zaznam, odchylka_pri_starte):
    ''' Vráti upravený záznam, v ktorom sú výšky upravené vzhľadom na počiatočnú chybu

    :param zaznam: záznam z výškomera
    :type zaznam: list of float
    :param odchylka_pri_starte: počiatočná chyba výškomera, <br /> kladná/záporná chyba -> výškomer meria viac /menej ako je skutočnosť
    :type zaznam: list of float
    :return: uprávený záznam z výškomera s korekciou chyby
    :rtype: int
    '''

    return [vyska - odchylka_pri_starte for vyska in zaznam]


def je_vrcholovka(zaznam):
    ''' Vráti, či trasa je typu „vrcholovka“

    Trasa na vrchol nikde neklesá -> rovina, stúpanie alebo začíname na vrchole

    Trasa z vrcholu nikde nestúpa -> rovina, klesanie alebo končíme na vrchole

    :param zaznam: záznam z výškomera
    :type zaznam: list of float
    :return: True, ak trasa je typu vrcholovka, inak False
    :rtype: bool
    '''
    idx = 0
    while idx < len(zaznam) - 1 and zaznam[idx] <= zaznam[idx + 1]:
        idx = idx + 1
    koniec_prveho_stupania = idx

    idx = len(zaznam) - 1
    while idx > koniec_prveho_stupania and zaznam[idx] <= zaznam[idx - 1]:
        idx = idx - 1
    zaciatok_posledneho_klesania = idx

    return koniec_prveho_stupania == zaciatok_posledneho_klesania


def pripoj_zaznam1(povodny, pridavany):  # Riešenie A
    ''' Upraví pôvodný záznam výšok tak, že na jeho koniec pridá údaje z pridávaného zoznamu.

    :param povodny: pôvodný záznam z výškomera
    :type povodny: list of float
    :param pridavany: pridávaný záznam z výškomera
    :type pridavany: list of float
    '''
    povodny.extend(pridavany[1:])


def pripoj_zaznam2(povodny, pridavany):  # Riešenie B
    ''' Upraví pôvodný záznam výšok tak, že na jeho koniec pridá údaje z pridávaného zoznamu.

    Výšky v pridávanom zázname upraví (posunie) tak, aby záznam v ňom zacínal na rovnakej výške ako pôvodný záznam končí.

    :param povodny: pôvodný záznam z výškomera
    :type povodny: list of float
    :param pridavany: pridávaný záznam z výškomera
    :type pridavany: list of float
    '''
    zmena = pridavany[0] - povodny[-1]
    pridavany_uprava = posun_vysky(pridavany[1:], zmena)
    povodny.extend(pridavany_uprava)


def vyhlad_zaznam(zaznam):  # Riešenie A
    ''' Vráti upravený záznam výšok. Záznam upraví tak, že každú hodnotu nahradí priemerom troch hodnôt v jej okolí.

    :param povodny: pôvodný záznam z výškomera
    :type povodny: list of float
    :return: upravený záznam výšok
    :rtype: list of float
    :raises ValueError: ak počet údajov menej ako 2
    '''
    if len(zaznam) < 2:  # Riešenie B
        raise ValueError('Záznam sa nedá vyhladiť. Malý počet údajov.')
    upraveny = []
    upraveny.append(sum(zaznam[:2]) / 2)
    for idx in range(1, len(zaznam)- 1):
        upraveny.append(sum(zaznam[idx - 1:idx + 2]) / 3)
    upraveny.append(sum(zaznam[-2:]) / 2)
    return upraveny


zaznam = [1, 2, 3, 2, 1, 2, 3, 4, 8, 12, 20, 19, 18, 17, 10, 9, 9, 2]
print(f'Záznam trasy: {zaznam}')

print(f'Trvanie trasy: {trvanie_trasy(zaznam)} min.')
print(f'Navyšší bod trasy: {najvyssi_bod(zaznam)} m n. m.')

print(f'Celkové stúpanie: {celkove_stupanie(zaznam)} m.')
print(f'Celkové klesanie: {celkove_klesanie(zaznam)} m.')

print(f'Čas najdlhšieho stúpania: {najdlhsie_stupanie(zaznam)} min.')
print(f'Čas najdlhšieho klesania: {najdlhsie_klesanie(zaznam)} min.')

korigovany_zaznam = posun_vysky(zaznam, -4)
print(f'Opravený záznam s chybou -4 m: {korigovany_zaznam}')

zaznam1 = [1, 2, 2, 2, 1]
print(f'Trasa {zaznam1} je typu vrcholovka: {je_vrcholovka(zaznam1)}.')

povodny = [1, 2, 3, 2, 1, 2, 3, 4, 8, 12, 20, 19, 18, 17, 10, 9, 9, 2]
print(f'Záznam trasy: {povodny}')
pripajany = [10, 15, 16]
pripoj_zaznam1(povodny, pripajany)
print(f'Záznam trasy po pripojení zaznamu {pripajany}: {povodny}')

povodny = [1, 2, 3, 2, 1, 2, 3, 4, 8, 12, 20, 19, 18, 17, 10, 9, 9, 2]
print(f'Záznam trasy: {povodny}')
pripajany = [10, 15, 16]
pripoj_zaznam2(povodny, pripajany)
print(f'Záznam trasy po pripojení zaznamu {pripajany}: {povodny}')

zaznam = [1, 2, 3, 2, 1, 2, 3, 4, 8, 12, 20, 19, 18, 17, 10, 9, 9, 2]
print(f'Záznam trasy: {zaznam}')
print(f'Vyhladený záznam: {vyhlad_zaznam(zaznam)}')
