import tkinter
from tkinter import messagebox


def urocenie(vklad, urokova_miera, pocet_rokov):
    ''' Vráti výslednú sumu pre zadaný vklad, úrokovú mieru a počet rokov úročenia

    :param vklad: vklad (istina)
    :type vklad: float
    :param urokova_miera: úroková miera v percentách
    :type urokova_miera: float
    :param pocet_rokov: počet rokov úročenie
    :type pocet_rokov: int
    :return: výsledná suma po úročení
    :rtype: float
    '''
    try:
        vklad = float(vklad)
        urokova_miera = float(urokova_miera)
        pocet_rokov = float(pocet_rokov)
    except ValueError:
        raise ValueError('Vklad, úroková miera a počet rokov musia byť číselné hodnoty!')
    if vklad < 0:
        raise ValueError('Vklad musí byť kladné číslo!')
    if urokova_miera < 0 or urokova_miera > 100:
        raise ValueError('Úroková miera musí byť v intervale <0, 100>!')
    if pocet_rokov < 0:
        raise ValueError('Počet rokov musí byť kladné číslo!')
    if pocet_rokov != int(pocet_rokov):
        raise ValueError('Počet rokov musí byť celé číslo!')
    vysledna_suma = vklad * (1 + urokova_miera / 100) ** pocet_rokov
    return vysledna_suma


def vypocet():
    try:
        vysledok = urocenie(s0.get(), p.get(), n.get())
    except ValueError as chyba:
        zobraz_chybu(chyba)
    else:
        s.set(vysledok)


def zobraz_chybu(chyba):
    messagebox.showerror('Chyba', chyba)


okno = tkinter.Tk()
okno.title('Výpočet zloženého úročenia')

tkinter.Label(okno, text='Zadaj počiatočný vklad:').grid(row=0, column=0)
s0 = tkinter.StringVar()
s0.set(1000)
tkinter.Entry(okno, textvariable=s0).grid(row=0, column=1)

tkinter.Label(okno, text='Zadaj úrokovú mieru:').grid(row=1, column=0)
p = tkinter.StringVar()
p.set(1)
tkinter.Entry(okno, textvariable=p).grid(row=1, column=1)

tkinter.Label(okno, text='Zadaj počet rokov úročenia:').grid(row=2, column=0)
n = tkinter.StringVar()
n.set(10)
tkinter.Entry(okno, textvariable=n).grid(row=2, column=1)

tkinter.Button(okno, text='Výpočet výslednej sumy', command=vypocet).grid(row=3, column=0)
s = tkinter.StringVar()
tkinter.Entry(okno, textvariable=s).grid(row=3, column=1)

tkinter.Button(okno, text='Koniec', command=okno.destroy).grid(row=4, column=0)

okno.mainloop()
