import math
import tkinter
from tkinter import messagebox


def vzdialenost(sirka1, dlzka1, sirka2, dlzka2):
    ''' Vráti vzdialenosť v kilometroch dvoch miest so zemepisnými súradnicami (sirka1, dlzka1) a (sirka2, dlzka2)

    :param sirka1: zemepisná širka miesta 1
    :type sirka1: float
    :param dlzka1: zemepisná dĺžka miesta 1
    :type dlzka1: float
    :param sirka2: zemepisná širka miesta 2
    :type sirka2: float
    :param dlzka2: zemepisná dĺžka miesta 2
    :type dlzka2: float
    :return: urocenie dvoch miest v kilometroch so zadanými zemepisnými súradnicami
    :rtype: float
    '''
    try:
        sirka1 = float(sirka1)
        dlzka1 = float(dlzka1)
        sirka2 = float(sirka2)
        dlzka2 = float(dlzka2)
    except ValueError:
        raise ValueError('Súradnice musia byť číselné hodnoty!')
    if sirka1 < -90 or sirka1 > 90:
        raise ValueError('Zemepisná šírka miesta 1 musí byť v intervale <-90, 90>!')
    if dlzka1 < -180 or dlzka1 > 180:
        raise ValueError('Zemepisná dĺžka miesta 1 musí byť v intervale <-180, 180>!')
    if sirka2 < -90 or sirka2 > 90:
        raise ValueError('Zemepisná šírka miesta 2 musí byť v intervale <-90, 90>!')
    if dlzka2 < -180 or dlzka2 > 180:
        raise ValueError('Zemepisná dĺžka miesta 2 musí byť v intervale <-180, 180>!')
    sirka1 = math.radians(sirka1)
    dlzka1 = math.radians(dlzka1)
    sirka2 = math.radians(sirka2)
    dlzka2 = math.radians(dlzka2)
    uhol = math.sin(sirka1) * math.sin(sirka2) + math.cos(sirka1) * math.cos(sirka2) * math.cos(dlzka2 - dlzka1)
    return 6371 * math.acos(uhol)


def vypocet():
    try:
        vysledok = vzdialenost(s1.get(), d1.get(), s2.get(), d2.get())
    except ValueError as chyba:
        zobraz_chybu(chyba)
    else:
        v.set(vysledok)


def zobraz_chybu(chyba):
    messagebox.showerror('Chyba', chyba)


okno = tkinter.Tk()
okno.title('Výpočet vzdialenosti 2 miest')

tkinter.Label(okno, text='Zadaj zemepisnú šírku miesta 1:').grid(row=0, column=0)
s1 = tkinter.StringVar()
s1.set(48.7172272)  # Košice
tkinter.Entry(okno, textvariable=s1).grid(row=0, column=1)

tkinter.Label(okno, text='Zadaj zemepisnú dĺžku miesta 1:').grid(row=1, column=0)
d1 = tkinter.StringVar()
d1.set(21.2496774)  # Košice
tkinter.Entry(okno, textvariable=d1).grid(row=1, column=1)

tkinter.Label(okno, text='Zadaj zemepisnú šírku miesta 2:').grid(row=2, column=0)
s2 = tkinter.StringVar()
s2.set(48.9975724)  # Prešov
tkinter.Entry(okno, textvariable=s2).grid(row=2, column=1)

tkinter.Label(okno, text='Zadaj zemepisnú dĺžku miesta 2:').grid(row=3, column=0)
d2 = tkinter.StringVar()
d2.set(21.2401811)  # Prešov
tkinter.Entry(okno, textvariable=d2).grid(row=3, column=1)

tkinter.Button(okno, text='Výpočet vzdialenosti miest (km)', command=vypocet).grid(row=4, column=0)
v = tkinter.StringVar()
tkinter.Entry(okno, textvariable=v).grid(row=4, column=1)

tkinter.Button(okno, text='Koniec', command=okno.destroy).grid(row=5, column=0)

okno.mainloop()
