import tkinter
from tkinter import messagebox


def kresli_mriezku():
    ''' Vykreslí štvorcovú mriežku s 9x9 uzlami s rozostupom 10 bodov

    '''
    for a in range(10, 180, 20):
        platno.create_line(a, 10, a, 170)
        platno.create_line(10, a, 170, a)


def zobraz_robota(x, y, farba):
    ''' Zobrazí robota na pozícii (x, y) ako kruh zadanej farby

    :param x: x-súradnica robota
    :type x: int
    :param y: y-súradnica robota
    :type y: int
    :param farba: farba robota, t.j. kruhu
    :type farba: str
    '''
    platno.create_oval(x - 5, y - 5, x + 5, y + 5, fill=farba)
    platno.update()
    platno.after(300)


def tah(x, y, prikaz):
    ''' Podľa zadaného príkazu a pôvodných súradníc vráti nové súradnice

    :param x: x-súradnica robota
    :type x: int
    :param y: y-súradnica robota
    :type y: int
    :param prikaz: zadaný príkaz
    :type prikaz: str
    :return: dvojica upravených súradníc robota
    :rtype: tuple of int
    '''
    if prikaz not in 'HDLP':
        raise ValueError('Na vstupe bol zadaný znak rôzny od znakov {H,D,L,P}.')
    elif prikaz == 'H':
        y = y - 20
    elif prikaz == 'D':
        y = y + 20
    elif prikaz == 'L':
        x = x - 20
    elif prikaz == 'P':
        x = x + 20
    if not (10 <= x <= 170 and 10 <= y <= 170):
        raise ValueError('Robot sa po danom príkaze dostal mimo hraciu plochu.')
    return x, y


def kresli():
    ''' Vykoná postupnosť príkazov robota a zobrazí ho na plátne

    '''
    zmaz()
    kresli_mriezku()
    zoznam = prikazy.get()
    x, y = 10, 10
    zobraz_robota(x, y, 'red')
    platno.create_oval(x - 5, y - 5, x + 5, y + 5, fill='red')
    try:
        for prikaz in zoznam:
            x, y = tah(x, y, prikaz)
            zobraz_robota(x, y, 'white')
    except ValueError as chyba:
        zobraz_chybu(chyba)
    else:
        zobraz_robota(x, y, 'lightgreen')


def zobraz_chybu(chyba):
    ''' Zobrazí chybu v novom okne

    :param chyba: chybové hlásenie
    :type chyba: ValueError
    '''
    messagebox.showerror('Chyba', chyba)


def zmaz():
    ''' Zmaže celý obsah plátna (vykreslené objekty)

    '''
    platno.delete('all')


okno = tkinter.Tk()
okno.title('Robot')
platno = tkinter.Canvas(okno, width=400, height=200, background="lightblue")

# riadok 0: Label, Entry, Button, Button
tkinter.Label(okno, text='Zadaj program: ').grid(row=0, column=0)

prikazy = tkinter.StringVar()
prikazy.set('PPPPPDDDDDDDLLLLHHHHPP')
tkinter.Entry(okno, textvariable=prikazy, width=40).grid(row=0, column=1)

tkinter.Button(okno, text='Kresli', command=kresli).grid(row=0, column=2)
tkinter.Button(okno, text='Zmaž', command=zmaz).grid(row=0, column=3)

# riadok 2: Canvas
platno.grid(row=1, column=0, columnspan=4)

okno.mainloop()
